==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ButtonClickEventArgsDescription } from "./ButtonClickEventArgsDescription";
/**
 * @hidden
 */
export let ButtonClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ButtonClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ButtonClickEventArgsDescriptionMetadata.a == null) {
                ButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ButtonClickEventArgsDescriptionMetadata.c(ButtonClickEventArgsDescriptionMetadata.a);
            }
            if (a.j(ButtonClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ButtonClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ButtonClickEventArgsDescriptionMetadata.b(a);
            a.aa("ButtonClickEventArgs", () => new ButtonClickEventArgsDescription());
            a.z("ButtonClickEventArgs", ButtonClickEventArgsDescriptionMetadata.a);
        }
    }
    ButtonClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ButtonClickEventArgsDescriptionMetadata, 'ButtonClickEventArgsDescriptionMetadata');
    ButtonClickEventArgsDescriptionMetadata.a = null;
    return ButtonClickEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ButtonClickEventArgsDescription } from "./ButtonClickEventArgsDescription";
/**
 * @hidden
 */
export let ButtonClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ButtonClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ButtonClickEventArgsDescriptionMetadata.a == null) {
                ButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ButtonClickEventArgsDescriptionMetadata.c(ButtonClickEventArgsDescriptionMetadata.a);
            }
            if (a.k(ButtonClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ButtonClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ButtonClickEventArgsDescriptionMetadata.b(a);
            a.ac("ButtonClickEventArgs", () => new ButtonClickEventArgsDescription());
            a.ab("ButtonClickEventArgs", ButtonClickEventArgsDescriptionMetadata.a);
        }
    }
    ButtonClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ButtonClickEventArgsDescriptionMetadata, 'ButtonClickEventArgsDescriptionMetadata');
    ButtonClickEventArgsDescriptionMetadata.a = null;
    return ButtonClickEventArgsDescriptionMetadata;
})();
